﻿using HeuristicLab.Clients.Access;
using HeuristicLab.Clients.Hive.WebJobManager.Services;
using System;
using System.Collections.Generic;
using System.Linq;
using System.ServiceModel.Security;
using System.Threading.Tasks;

namespace HeuristicLab.Clients.Hive.WebJobManager.Models
{
    public class HiveWebUser
    {
        private WebLoginService weblog;
        private string username;
        public bool OKBOnly { get; set; }
        public Guid webIdToken { get; set; }
        public User currentUser { get; set; }
        public List<UserGroup> subscribedGroups { get; set; }
        public List<Role> accessRoles { get; set; }

        public HiveWebUser(Guid token, string username, bool okb)
        {
            webIdToken = token;
            this.username = username;
            this.weblog = WebLoginService.Instance;
            OKBOnly = okb;
            updateUserInfo();
        }
        public HiveWebUser updateUserInfo()
        {
            
            try
            {
                if (OKBOnly)
                    throw new SecurityAccessDeniedException();
                var access = weblog.getAccessAdminClient(webIdToken);
                access.RefreshUsers();
                access.RefreshUserGroups();
                access.RefreshRoles();
            
                currentUser = access.Users.Find(x => x.UserName == username);
                subscribedGroups = access.CallAccessService(x => x.GetUserGroupsOfUser(currentUser.Id));
                accessRoles = access.CallAccessService(x => x.GetRolesOfCurrentUser());
            }
            catch(SecurityAccessDeniedException e)
            {
                currentUser = new User();
                currentUser.FullName = username;
                subscribedGroups = new List<UserGroup>();
                accessRoles = new List<Role>();
            }
            
            return this;

        }
        public bool HasUserAdminAccess()
        {
            if(accessRoles.Find(x => x.Name == "AccessService Administrator") != null)
            {
                return true;
            }
            return false;
        }
        public bool hasResourceAdminAccess()
        {
            if(accessRoles.Find(x =>x.Name == "Hive Administrator" ) != null
                && accessRoles.Find(x => x.Name == "AccessService Administrator") != null)
            {
                return true;
            }
            return false;
        }
        public bool hasOKBAccess()
        {
            if (OKBOnly || accessRoles.Find(x => x.Name == "OKB User") != null || accessRoles.Find(x => x.Name == "OKB Administrator") != null)
            {
                return true;
            }
            return false;
        }
    }
}
